pub struct AnnotationConfig {
pub upstream_distance: u64,
pub downstream_distance: u64,
pub splice_window: u64,
}Expand description
Configuration for variant annotation.
Fields
upstream_distance: u64Distance upstream of a gene to annotate as “Upstream” (default 5000).
downstream_distance: u64Distance downstream of a gene to annotate as “Downstream” (default 5000).
splice_window: u64Number of bases into the intron to consider as splice site (default 2).