pub enum ColumnData {
Strings(Vec<String>),
Numeric(Vec<f64>),
Categorical {
codes: Vec<i32>,
categories: Vec<String>,
},
}Expand description
A metadata column with typed data.
Supports string, numeric, and categorical columns as found in .h5ad files.
Variants
Strings(Vec<String>)
Free-text string values.
Numeric(Vec<f64>)
Numeric (f64) values.
Categorical
Categorical data stored as integer codes indexing into a category list.
Implementations
Sourceimpl ColumnData
impl ColumnData
Sourcepub fn as_strings(&self) -> Option<&Vec<String>>
pub fn as_strings(&self) -> Option<&Vec<String>>
Try to get as string slice. Returns None if not Strings variant.
Sourcepub fn as_numeric(&self) -> Option<&Vec<f64>>
pub fn as_numeric(&self) -> Option<&Vec<f64>>
Try to get as numeric slice. Returns None if not Numeric variant.